@@ -41,8 +41,6 @@
 
 #define KLEO_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 #if defined(KLEO_NO_DEPRECATED)
 #  undef KLEO_DEPRECATED
 #  define KLEO_DEPRECATED_EXPORT KLEO_EXPORT
@@ -63,7 +61,7 @@
 #define KLEO_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KLEO_NO_DEPRECATED
-#  define KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51701
+#  define KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51703
 #endif
 #ifdef KLEO_NO_DEPRECATED_WARNINGS
 #  define KLEO_DEPRECATED_WARNINGS_SINCE 0
@@ -73,7 +71,7 @@
 #  ifdef KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KLEO_DEPRECATED_WARNINGS_SINCE KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KLEO_DEPRECATED_WARNINGS_SINCE 0x51701
+#    define KLEO_DEPRECATED_WARNINGS_SINCE 0x51703
 #  endif
 #endif
 
@@ -82,7 +80,7 @@
 #endif
 
 #ifdef KLEO_DEPRECATED
-#  define KLEO_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KLEO_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KLEO_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
